@@ -1,6 +1,6 @@
 package WebService::Shutterstock::Client;
 {
-  $WebService::Shutterstock::Client::VERSION = '0.005';
+  $WebService::Shutterstock::Client::VERSION = '0.006';
 }
 
 # ABSTRACT: Provides easy REST interactions with the Shutterstock API
@@ -102,13 +102,13 @@ sub process_response {
 	}
 }
 
-sub new {
-	my $self = shift->SUPER::new(@_);
+
+sub BUILD {
+	my $self = shift;
 	if($ENV{SS_API_DEBUG}){
 		$self->getUseragent->add_handler("request_send",  sub { shift->dump(prefix => '> '); return });
 		$self->getUseragent->add_handler("response_done", sub { shift->dump(prefix => '< '); return });
 	}
-	return $self;
 }
 
 1;
@@ -123,7 +123,7 @@ WebService::Shutterstock::Client - Provides easy REST interactions with the Shut
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 DESCRIPTION
 
@@ -144,6 +144,8 @@ Processes the most recent response object based on the HTTP status code,
 the content type and response body.  Additional handlers may be passed in
 (keyed on HTTP status codes).
 
+=for Pod::Coverage BUILD
+
 =head1 AUTHOR
 
 Brian Phillips <bphillips@cpan.org>
